<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013-2014 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\ImiaPageteaser\Domain\Model;

use TYPO3\CMS\Extbase\Persistence\ObjectStorage;
use IMIA\ImiaBaseExt\Annotation\SQL;
use IMIA\ImiaBaseExt\Annotation\TCA;

/**
 * @package     imia_pageteaser
 * @subpackage  Domain\Model
 * @author      David Frerich <d.frerich@imia.de>
 *
 * @TCA\Table(
 *  types = {
 *      100: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.metadata, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.metatags;metatags, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      103: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      104: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcut;shortcut, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcutpage;shortcutpage, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      106: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;filepalette, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      110: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.metadata, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.metatags;metatags, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      111: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      112: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      113: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      114: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcut;shortcut, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcutpage;shortcutpage, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      115: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, gallery_pdf, categories, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, tx_templavoila_flex;;;;1-1-1, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;visibility, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.behaviour, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.caching;caching, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.language;language, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      116: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;filepalette, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      120: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.metadata, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.metatags;metatags, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      123: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      124: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcut;shortcut, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcutpage;shortcutpage, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      126: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;filepalette, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      130: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.metadata, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.metatags;metatags, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      133: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      134: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcut;shortcut, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcutpage;shortcutpage, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      136: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;filepalette, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      140: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;standard, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.metadata, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.metatags;metatags, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      143: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.external;external, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      144: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcut;shortcut, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.shortcutpage;shortcutpage, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media",
 *      146: "--palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.standard;filepalette, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.title;title, --div--;LLL::page_tab_content, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.abstract;abstract, teaser_image, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.editorial;editorial, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.access, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.visibility;hiddenonly, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.access;access, --div--;LLL:EXT:cms/locallang_tca.xml:pages.tabs.resources, --palette--;LLL:EXT:cms/locallang_tca.xml:pages.palettes.media;media"
 *  },
 *  palettes = {
 *      "filepalette": "doktype;LLL:EXT:cms/locallang_tca.xlf:pages.doktype_formlabel, sys_language_uid, --linebreak--, file",
 *  }
 * )
 */
class PageAlt extends \IMIA\ImiaBaseExt\Domain\Model\PageLanguageOverlay
{
    /**
     * @var \TYPO3\CMS\Core\Resource\FileRepository
     * @inject
     * @FIXME How to do this a better way?
     */
    protected $fileRepository;

    /**
     * @SQL\Column(name="pid", create=false)
     * @var \IMIA\ImiaPageteaser\Domain\Model\Page
     * @lazy
     */
    protected $page;

    /**
     * @TCA\Select(
     *  items = {
     *      99: {"LLL::page_doktype_divider_news", "--div--"},
     *      100: {"LLL::page_doktype_news", 100, "EXTREL::Resources/Public/Images/Icons/PageDoktypeNews.png"},
     *      101: {"LLL::page_doktype_news_shortcut", 104, "EXTREL::Resources/Public/Images/Icons/PageDoktypeNewsShortcut.png"},
     *      102: {"LLL::page_doktype_news_external", 103, "EXTREL::Resources/Public/Images/Icons/PageDoktypeNewsExternal.png"},
     *      103: {"LLL::page_doktype_news_file", 106, "EXTREL::Resources/Public/Images/Icons/PageDoktypeNewsFile.png"},
     *      109: {"LLL::page_doktype_divider_gallery", "--div--"},
     *      110: {"LLL::page_doktype_gallery", 110, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGallery.png"},
     *      112: {"LLL::page_doktype_gallery_shortcut", 114, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryShortcut.png"},
     *      113: {"LLL::page_doktype_gallery_external", 113, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryExternal.png"},
     *      114: {"LLL::page_doktype_gallery_images", 111, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryImages.png"},
     *      115: {"LLL::page_doktype_gallery_video", 112, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryVideo.png"},
     *      116: {"LLL::page_doktype_gallery_pdf", 115, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryPdf.png"},
     *      117: {"LLL::page_doktype_gallery_file", 116, "EXTREL::Resources/Public/Images/Icons/PageDoktypeGalleryFile.png"},
     *      119: {"LLL::page_doktype_divider_product", "--div--"},
     *      120: {"LLL::page_doktype_product", 120, "EXTREL::Resources/Public/Images/Icons/PageDoktypeProduct.png"},
     *      122: {"LLL::page_doktype_product_shortcut", 124, "EXTREL::Resources/Public/Images/Icons/PageDoktypeProductShortcut.png"},
     *      123: {"LLL::page_doktype_product_external", 123, "EXTREL::Resources/Public/Images/Icons/PageDoktypeProductExternal.png"},
     *      124: {"LLL::page_doktype_product_file", 126, "EXTREL::Resources/Public/Images/Icons/PageDoktypeProductFile.png"},
     *      129: {"LLL::page_doktype_divider_event", "--div--"},
     *      130: {"LLL::page_doktype_event", 130, "EXTREL::Resources/Public/Images/Icons/PageDoktypeEvent.png"},
     *      132: {"LLL::page_doktype_event_shortcut", 134, "EXTREL::Resources/Public/Images/Icons/PageDoktypeEventShortcut.png"},
     *      133: {"LLL::page_doktype_event_external", 133, "EXTREL::Resources/Public/Images/Icons/PageDoktypeEventExternal.png"},
     *      134: {"LLL::page_doktype_event_file", 136, "EXTREL::Resources/Public/Images/Icons/PageDoktypeEventFile.png"},
     *      139: {"LLL::page_doktype_divider_article", "--div--"},
     *      140: {"LLL::page_doktype_article", 140, "EXTREL::Resources/Public/Images/Icons/PageDoktypeArticle.png"},
     *      142: {"LLL::page_doktype_article_shortcut", 144, "EXTREL::Resources/Public/Images/Icons/PageDoktypeArticleShortcut.png"},
     *      143: {"LLL::page_doktype_article_external", 143, "EXTREL::Resources/Public/Images/Icons/PageDoktypeArticleExternal.png"},
     *      144: {"LLL::page_doktype_article_file", 146, "EXTREL::Resources/Public/Images/Icons/PageDoktypeArticleFile.png"},
     *  }
     * )
     *
     * @var integer
     */
    protected $doktype;

    /**
     * @var boolean
     */
    protected $hidden;

    /**
     * @var \DateTime
     */
    protected $starttime;

    /**
     * @var \DateTime
     */
    protected $endtime;

    /**
     * @SQL\Column(type="int", length=11, nullable=false)
     * @TCA\ImageFiles(
     *  l10n_mode = "mergeIfNotBlank",
     *  maxitems = 1,
     *  foreign_types = {
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_IMAGE: {"showitem": "title,alternative;;;;3-3-3,--palette--;;filePalette" }
     *  }
     * )
     * @TCA\AddToTypes(position="after:abstract")
     *
     * @var integer
     */
    protected $teaserImage;

    /**
     * @var array
     */
    protected $media;

    /**
     * @SQL\Column(type="int", length=11, nullable=false)
     * @TCA\ImageFiles(
     *  l10n_mode = "mergeIfNotBlank",
     *  foreign_types = {
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_IMAGE: {"showitem": "title,alternative;;;;3-3-3,description,--palette--;;filePalette" }
     *  }
     * )
     *
     * @var integer
     */
    protected $galleryImages;

    /**
     * @SQL\Column(type="int", length=11, nullable=false)
     * @TCA\Files(
     *  l10n_mode = "mergeIfNotBlank",
     *  foreign_types = {
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_UNKNOWN: {"showitem": "--palette--;;filePalette" },
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_TEXT: {"showitem": "--palette--;;filePalette" },
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_IMAGE: {"showitem": "--palette--;;filePalette" },
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_AUDIO: {"showitem": "--palette--;;filePalette" },
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_VIDEO: {"showitem": "--palette--;;filePalette" },
     *      \TYPO3\CMS\Core\Resource\File::FILETYPE_APPLICATION: {"showitem": "--palette--;;filePalette" },
     *  },
     *  maxitems = 1,
     * )
     *
     * @var int
     */
    protected $file;

    /**
     * @SQL\Column(type="int", length=11)
     * @TCA\FilesPDF(
     *  maxitems = 1
     * )
     *
     * @var integer
     */
    protected $galleryPdf;

    /**
     * @return \TYPO3\CMS\Core\Resource\FileReference
     * @FIXME How to do this a better way?
     */
    public function getTeaserImage()
    {
        if (!$this->teaserImage || !is_object($this->teaserImage)) {
            $files = $this->fileRepository->findByRelation('pages_language_overlay', 'teaser_image', $this->uid);

            if (count($files) > 0) {
                $this->teaserImage = array_shift($files);
            } elseif (!$this->teaserImage && $this->getPage() && is_object($this->getPage())) {
                $this->teaserImage = $this->getPage()->getTeaserImage();
            } else {
                $this->teaserImage = null;
            }
        }

        return $this->teaserImage;
    }

    /**
     * @return \TYPO3\CMS\Core\Resource\FileReference
     * @FIXME How to do this a better way?
     */
    public function getMedia()
    {
        if (!$this->media || !is_object($this->media)) {
            $files = $this->fileRepository->findByRelation('pages_language_overlay', 'media', $this->uid);

            if (count($files) > 0) {
                $this->media = $files;
            } elseif (!$this->media && $this->getPage() && is_object($this->getPage())) {
                $this->media = $this->getPage()->getMedia();
            } else {
                $this->media = array();
            }
        }

        return $this->media;
    }

    /**
     * @return \TYPO3\CMS\Core\Resource\FileReference
     * @FIXME How to do this a better way?
     */
    public function getGalleryImages()
    {
        if (!$this->galleryImages || !is_object($this->galleryImages)) {
            $files = $this->fileRepository->findByRelation('pages_language_overlay', 'gallery_images', $this->uid);

            if (count($files) > 0) {
                $this->galleryImages = $files;
            } elseif (!$this->galleryImages && $this->getPage() && is_object($this->getPage())) {
                $this->galleryImages = $this->getPage()->getGalleryImages();
            } else {
                $this->galleryImages = null;
            }
        }

        return $this->galleryImages;
    }

    /**
     * @return \TYPO3\CMS\Core\Resource\FileReference
     * @FIXME How to do this a better way?
     */
    public function getGalleryPdf()
    {
        if (!$this->galleryPdf || !is_object($this->galleryPdf)) {
            $files = $this->fileRepository->findByRelation('pages_language_overlay', 'gallery_pdf', $this->uid);

            if (count($files) > 0) {
                $this->galleryPdf = array_shift($files);
            } elseif (!$this->galleryPdf && $this->getPage() && is_object($this->getPage())) {
                $this->galleryPdf = $this->getPage()->getGalleryPdf();
            } else {
                $this->galleryPdf = null;
            }
        }

        return $this->galleryPdf;
    }

    /**
     * @return integer
     * @FIXME Very dirty, but is there a better way?
     */
    public function getContentFileRelations()
    {
        if ($this->getPage() && is_object($this->getPage())) {
            return $this->getPage()->getContentFileRelations();
        } else {
            return null;
        }
    }

    /**
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\IMIA\ImiaPageteaser\Domain\Model\Category>
     */
    public function getCategories()
    {
        if ($this->getPage() && is_object($this->getPage())) {
            return $this->getPage()->getCategories();
        } else {
            return null;
        }
    }

    /**
     * @return \IMIA\ImiaPageteaser\Domain\Model\Category
     */
    public function getCategory()
    {
        if ($this->getPage() && is_object($this->getPage())) {
            return $this->getPage()->getCategory();
        } else {
            return null;
        }
    }

    /*
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\IMIA\ImiaPageteaser\Domain\Model\Page>
     */
    public function getTeaserPages()
    {
        if ($this->getPage() && is_object($this->getPage())) {
            return $this->getPage()->getTeaserPages();
        } else {
            return null;
        }
    }

    /**
     * @return \IMIA\ImiaPageteaser\Domain\Model\Page
     */
    public function getPage()
    {
        return $this->page;
    }

    /**
     * @param \IMIA\ImiaPageteaser\Domain\Model\Page $page
     * @return \IMIA\ImiaPageteaser\Domain\Model\PageAlt
     */
    public function setPage(\IMIA\ImiaPageteaser\Domain\Model\Page $page)
    {
        $this->page = $page;

        return $this;
    }

    /**
     * @return array
     */
    public function toArray()
    {
        $page = array();
        foreach (get_class_methods($this) as $method) {
            if (substr($method, 0, 3) === 'get') {
                $property = lcfirst(substr($method, 3));
                $value = $this->$method();

                if (is_object($value)) {
                    switch (get_class($value)) {
                        case 'DateTime':
                            $page[$property] = $value->getTimestamp();
                            break;
                        default:
                            try {
                                //$page[$property] = (string)$value;
                            } catch(\Exception $e) {};
                            break;
                    }
                } else {
                    $page[$property] = $value;
                }
            }
        }

        return $page;
    }

    /**
     * @return boolean
     */
    public function getHidden()
    {
        return $this->hidden;
    }

    /**
     * @return mixed
     */
    public function getStarttime()
    {
        return $this->starttime;
    }

    /**
     * @return \DateTime
     */
    public function getEndtime()
    {
        return $this->endtime;
    }

    /**
     * @return boolean
     */
    public function getIsLanguageVisible()
    {
        return true;
    }

    /*
     * @param integer $sysLanguageUid
     * @return boolean
     */
    public function hasTranslation($sysLanguageUid)
    {
        if ($this->getPage() && is_object($this->getPage())) {
            return $this->getPage()->hasTranslation($sysLanguageUid);
        } else {
            return false;
        }
    }

    /*
     * @return array
     */
    public function getTranslations()
    {
        if ($this->getPage() && is_object($this->getPage())) {
            $translations = $this->getPage()->getTranslations();
            unset($translations[$this->getRecordUid()]);

            return $translations;
        } else {
            return false;
        }
    }


    /**
     * @return \TYPO3\CMS\Core\Resource\FileReference
     * @FIXME How to do this a better way?
     */
    public function getFile()
    {
        if (!$this->file || !is_object($this->file)) {
            $files = $this->fileRepository->findByRelation('pages_language_overlay', 'file', $this->uid);

            if ($files && count($files) > 0) {
                $this->file = array_shift($file);
            } elseif (!$this->file && $this->getPage() && is_object($this->getPage())) {
                $this->file = $this->getPage()->getFile();
            } else {
                $this->file = null;
            }
        }

        return $this->file;
    }
}