<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\ImiaPageteaser\Xclass\ImiaBigpipe\Xclass\Frontend\Controller;

if (class_exists('IMIA\ImiaBigpipe\Xclass\Frontend\Controller\TypoScriptFrontendController')):

/**
 * @package     imia_pageteaser
 * @subpackage  Xclass
 * @author      David Frerich <d.frerich@imia.de>
 */
class TypoScriptFrontendController extends \IMIA\ImiaBigpipe\Xclass\Frontend\Controller\TypoScriptFrontendController
{
    /**
     * @var array
     */
    protected $shortcutDoktypes = array(104, 114, 124, 134, 144);

    /**
     * @throws \TYPO3\CMS\Core\Error\Http\ServiceUnavailableException
     */
	public function getPageAndRootline()
    {
        parent::getPageAndRootline();

		if (in_array($this->page['doktype'], $this->shortcutDoktypes)) {
            $this->MP = '';
			$this->originalShortcutPage = $this->page;
			$this->page = $this->getPageShortcut($this->page['shortcut'], $this->page['shortcut_mode'], $this->page['uid']);
			$this->id = $this->page['uid'];

            // Gets the rootLine
            $this->rootLine = $this->sys_page->getRootLine($this->id, $this->MP);
            // If not rootline we're off...
            if (!count($this->rootLine)) {
                $ws = $this->whichWorkspace();
                if ($this->sys_page->error_getRootLine_failPid == -1 && $ws) {
                    $this->sys_page->versioningPreview = TRUE;
                    $this->versioningWorkspaceId = $ws;
                    $this->rootLine = $this->sys_page->getRootLine($this->id, $this->MP);
                }
                if (!count($this->rootLine)) {
                    $message = 'The requested page didn\'t have a proper connection to the tree-root!';
                    if ($this->checkPageUnavailableHandler()) {
                        $this->pageUnavailableAndExit($message);
                    } else {
                        $rootline = '(' . $this->sys_page->error_getRootLine . ')';
                        \TYPO3\CMS\Core\Utility\GeneralUtility::sysLog($message, 'cms', \TYPO3\CMS\Core\Utility\GeneralUtility::SYSLOG_SEVERITY_ERROR);
                        throw new \TYPO3\CMS\Core\Error\Http\ServiceUnavailableException($message . '<br /><br />' . $rootline, 1301648167);
                    }
                }
                $this->fePreview = 1;
            }
            // Checking for include section regarding the hidden/starttime/endtime/fe_user (that is access control of a whole subbranch!)
            if ($this->checkRootlineForIncludeSection()) {
                if (!count($this->rootLine)) {
                    $message = 'The requested page was not accessible!';
                    if ($this->checkPageUnavailableHandler()) {
                        $this->pageUnavailableAndExit($message);
                    } else {
                        \TYPO3\CMS\Core\Utility\GeneralUtility::sysLog($message, 'cms', \TYPO3\CMS\Core\Utility\GeneralUtility::SYSLOG_SEVERITY_ERROR);
                        throw new \TYPO3\CMS\Core\Error\Http\ServiceUnavailableException($message, 1301648234);
                    }
                } else {
                    $el = reset($this->rootLine);
                    $this->id = $el['uid'];
                    $this->page = $this->sys_page->getPage($this->id);
                    $this->rootLine = $this->sys_page->getRootLine($this->id, $this->MP);
                }
            }
		}
	}

	/**
	 * @param integer $SC
	 * @param integer $mode
	 * @param integer $thisUid
	 * @param integer $itera
	 * @param array $pageLog
	 * @return mixed
     * @throws \RuntimeException
     */
	public function getPageShortcut($SC, $mode, $thisUid, $itera = 20, $pageLog = array())
    {
        $page = parent::getPageShortcut($SC, $mode, $thisUid, $itera, $pageLog);

		// Check if short cut page was a shortcut itself, if so look up recursively:
		if (in_array($page['doktype'], $this->shortcutDoktypes)) {
			if (!in_array($page['uid'], $pageLog) && $itera > 0) {
				$pageLog[] = $page['uid'];
				$page = $this->getPageShortcut($page['shortcut'], $page['shortcut_mode'], $page['uid'], $itera - 1, $pageLog);
			} else {
				$pageLog[] = $page['uid'];
				$message = 'Page shortcuts were looping in uids ' . implode(',', $pageLog) . '...!';
				\TYPO3\CMS\Core\Utility\GeneralUtility::sysLog($message, 'cms', \TYPO3\CMS\Core\Utility\GeneralUtility::SYSLOG_SEVERITY_ERROR);
				throw new \RuntimeException($message, 1294587212);
			}
		}

		return $page;
	}

    /**
     */
	public function checkPageForShortcutRedirect()
    {
		if (!empty($this->originalShortcutPage) && in_array($this->originalShortcutPage['doktype'], $this->shortcutDoktypes)) {
			$this->calculateLinkVars();
			// instantiate tslib_content to generate the correct target URL
			/** @var $cObj \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer */
			$cObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Frontend\\ContentObject\\ContentObjectRenderer');
			$parameter = $this->page['uid'];
			$type = \TYPO3\CMS\Core\Utility\GeneralUtility::_GET('type');
			if ($type) {
				$parameter .= ',' . $type;
			}
			$redirectUrl = $cObj->typoLink_URL(array('parameter' => $parameter));
			// HTTP Status code header - dependent on shortcut type
			$redirectStatus = \TYPO3\CMS\Core\Utility\HttpUtility::HTTP_STATUS_301;
			if ($this->originalShortcutPage['shortcut_mode'] == \TYPO3\CMS\Frontend\Page\PageRepository::SHORTCUT_MODE_RANDOM_SUBPAGE) {
				$redirectStatus = \TYPO3\CMS\Core\Utility\HttpUtility::HTTP_STATUS_307;
			}
			// redirect and exit
			\TYPO3\CMS\Core\Utility\HttpUtility::redirect($redirectUrl, $redirectStatus);
		}
	}
}

endif;